/**
 * Clase Graphics.java Extendida de la clase abstracta Equipment para la definicion de los metodos necesarios para la
 * generacion de los graficos solicitados
 * @author Eduardo Garcia, Sebastian Contreras
 */
import java.awt.*;
import java.awt.geom.*;
import javax.swing.*;
import javax.swing.event.*;
import javax.imageio.*;
import java.io.*;
import java.awt.image.*;
import java.net.*;
import java.applet.*;

public class Graphics extends Equipment{
    
    
/**
 * Contructor de Graficos
 * @param name Nombre del grafico particular
 * @param position Posicion del grafico dentro de la aplicacion o applet
 * @param view Visor para grafico
 * @param id Identificador del grafico
 * @param tank Tanque que recibe los parametros a graficar
 * @param controller Controlador que utiliza como formula a graficar
 */
	public Graphics(String name, Point position, PlantView view, int id, Tank tank,Controller controller){
            this.name = name;
            this.position = position;
            this.controller = controller;
            this.view = view;
            this.id=id;		
            this.tank=tank;
            gui = new Box(BoxLayout.Y_AXIS);
            valve = new Point[time_lim];
            level = new Point[time_lim];
            reference = new Point[time_lim];
            special = new SpecialFunctions();
            
	}	
/**
 * Metodo para dibujar el contenido del panel
 * @param g2d Nombre del grafico
 */
	public void paint(Graphics2D g2d){                  
           GraphicBase(g2d, width, high, name);
            if(time==time_lim-1){ 
                time=0;
                aux = 0;
                special.Reset(level, valve, reference, time_lim);                    	
            }
            else time++;
            if(time%5 == 0){
                aux++;
		valve[aux] = new Point(position.x+aux,position.y-(int)(tank.getOutValve()*100));
		level[aux] = new Point(position.x+aux,position.y-(int)(tank.getLevel()));
		reference[aux] = new Point(position.x+aux,position.y-(int)controller.getRef());
                }
		special.Speaker(high, g2d, tank, id, position);                		
		special.LinkPoints(i,id, time_lim, valve, level, reference, g2d);		
	}
/**
 * Metodo para retornar la interfaz de usuario utilizada en la aplicacion
 * @return gui Interfaz de usuario
 */
	public Box getGUI(){
		return gui;
	}
/**
 * Metodo para establecer el repintado en el grafico para mostrar punto a punto su avance
 * @param dt Intervalo de tiempo
 */
	public void timeTick(float dt){
		view.repaint();         
	}
/**
 * Metodo para generar el grafico base de la forma en ejes coordenados
 * @param g2d Grafico a ser dibujado en particular
 * @param width Ancho del grafico
 * @param high Largo del grafico
 * @param name Nombre del grafico
 */
        private void GraphicBase(Graphics2D g2d, int width, int high, String name) {           
            
            g2d.setColor(Color.ORANGE);
            g2d.drawLine(position.x+width/4-5, position.y-115, position.x+width/4+115, position.y-115);
            g2d.drawLine(position.x+width/4-10, position.y-113, position.x+width/4+120, position.y-113);
            g2d.setColor(Color.GREEN);
            g2d.drawString(name + " Graphic ",position.x+width/4,position.y-120);
            g2d.drawString("X_Axis",position.x+width,position.y+20);
            g2d.drawString("Y_Axis",position.x-30,position.y-high);
            for(j = 0;j<=width;j++)
                if(j%10 == 0){                    
                    g2d.drawLine(position.x+j, position.y-2, position.x+j, position.y+2);
                }
            for(j = 0;j<=high;j++)
                if(j%10 == 0){
                    g2d.drawLine(position.x-2, position.y-high+j, position.x+2, position.y-high+j);                    
                }
            g2d.setColor(Color.BLUE);
            g2d.drawLine(position.x,position.y,position.x+width,position.y);
            g2d.drawLine(position.x,position.y-high,position.x,position.y);            
            
            if(id==1){			
                g2d.drawString("Tank Level  "+id+" [1/100]",position.x+150+15,position.y-high/3-65);
                g2d.drawString("Tank Valve "+id,position.x+150+15,position.y-high/3-50);
                g2d.setColor(Color.BLUE);
                g2d.fill(new Rectangle2D.Double(position.x+150,position.y-high/3-60,15,10));		
		g2d.setColor(Color.ORANGE);
                g2d.fill(new Rectangle2D.Double(position.x+150,position.y-high/3-75,15,10));                
		}
            else{			
                g2d.drawString("Tank Level "+id+" [1/100]",position.x+150+15,position.y-high/3-65);
                g2d.drawString("Tank Valve "+id,position.x+150+15,position.y-high/3-50);
                g2d.drawString("Ref Level [1/100] ",position.x+150+15,position.y-high/3-35);
                g2d.setColor(Color.BLUE);
                g2d.fill(new Rectangle2D.Double(position.x+150,position.y-high/3-60,15,10));			
		g2d.setColor(Color.ORANGE);
                g2d.fill(new Rectangle2D.Double(position.x+150,position.y-high/3-75,15,10));                        
		g2d.setColor(Color.RED);
                g2d.fill(new Rectangle2D.Double(position.x+150,position.y-high/3-45,15,10));                        
		}        
    }
        
        private SpecialFunctions special;	
	private Controller controller;
	private int id, time = 0, time_lim = 900, width=200, high=100, i, aux=0, j;
	private Point[] valve, level, reference;
	private Tank tank;
	private Point position;
	private Box gui;
	private PlantView view;       
        private String name;
    

}
