/**
* Clase para la generacion del panel para la planta
* @author Eduardo Garcia, Sebastian Contreras
*/

import java.awt.*;
import javax.swing.*;
import javax.swing.border.*;

/**
   A panel with two tanks and a control system. A simulation to practice 
   with applets.
*/
public class PlantPanel extends JPanel
{    
   public PlantPanel()
   {  
       
       setLayout(new BorderLayout());
       menuPanel= new Box(BoxLayout.Y_AXIS);       
       menuPanel.setBorder(new EmptyBorder(5,3,1,3));
       view= new PlantView();
       view.setPreferredSize(new Dimension(800,400));
      
       dt=0.05F; // 50 ms is the delta t of the simulation. 
       TimePace timer = new TimePace(this);
       menuPanel.add(timer.getGUI());
       menuPanel.add(Box.createRigidArea(new Dimension(10,0)));        
      
       Tank tank1= new Tank(new Point(70,120), view, 1);
       menuPanel.add(tank1.getGUI());
       menuPanel.add(Box.createRigidArea(new Dimension(10,0)));
       view.addEquipment(tank1);
      
       Tank tank2= new Tank(new Point(130,225), view, 2);
       menuPanel.add(tank2.getGUI());
       menuPanel.add(Box.createRigidArea(new Dimension(10,0)));
       view.addEquipment(tank2);
       
       tank1.setReceiver(tank2);
      
       Controller control = new Controller(new Point(50,280), tank2);
       view.addEquipment(control);
       menuPanel.add(Box.createRigidArea(new Dimension(10,0)));
       menuPanel.add(control.getGUI());
       
       add(menuPanel, BorderLayout.EAST);
       add(view, BorderLayout.CENTER);  
       
       
       //Se generan graficos paraticulares para el primer y segundo estanque
      
       graph1 = new Graphics("First Tank ",new Point(500,200),view,1,tank1,control);      
       
       menuPanel.add(graph1.getGUI());
       menuPanel.add(Box.createRigidArea(new Dimension(10,0)));
       view.addEquipment(graph1);
      
       graph2 = new Graphics("Second Tank",new Point(500,350),view,2,tank2,control);      
       
       menuPanel.add(graph2.getGUI());
       menuPanel.add(Box.createRigidArea(new Dimension(10,0)));
       view.addEquipment(graph2); 
       
      
      timer.start();
   }
   public void simulationTick(){
	   view.timeTick(dt);
	   view.repaint();
   }
   private Graphics graph1, graph2;
   private JComponent menuPanel;
   private PlantView view;
   private float dt;  
}
